@@ -17,6 +17,7 @@
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 
+__version__ = "0.0.3"
+
 from .server import Server
 from .client import Client
-from . import pack
